==> cscec5b-rmat-impl-3.0.1-20230609.071328-202-sources.jar: com/ejianc/business/rmat/vo/RentReportVO.java <==
package com.ejianc.business.rmat.vo;

import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 项目租金报表
 *
 * @author generator
 *
 */
public class RentReportVO {
    private static final long serialVersionUID = 1L;

    private Long id;
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date beginDate;
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date endDate;
    private BigDecimal totalMny;
    private BigDecimal rentMny;
    private BigDecimal otherMny;

    private List<RentReportDetailVO> detailList = new ArrayList<>();
    private List<RentReportRestituteVO> restituteList = new ArrayList<>();
    private List<RentReportRepairVO> repairList = new ArrayList<>();
    private List<RentReportOtherVO> otherList = new ArrayList<>();
    private List<RentReportCalcVO> calcList = new ArrayList<>();

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public BigDecimal getTotalMny() {
        return totalMny;
    }

    public void setTotalMny(BigDecimal totalMny) {
        this.totalMny = totalMny;
    }

    public BigDecimal getRentMny() {
        return rentMny;
    }

    public void setRentMny(BigDecimal rentMny) {
        this.rentMny = rentMny;
    }

    public BigDecimal getOtherMny() {
        return otherMny;
    }

    public void setOtherMny(BigDecimal otherMny) {
        this.otherMny = otherMny;
    }

    public List<RentReportDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<RentReportDetailVO> detailList) {
        this.detailList = detailList;
    }

    public List<RentReportRestituteVO> getRestituteList() {
        return restituteList;
    }

    public void setRestituteList(List<RentReportRestituteVO> restituteList) {
        this.restituteList = restituteList;
    }

    public List<RentReportRepairVO> getRepairList() {
        return repairList;
    }

    public void setRepairList(List<RentReportRepairVO> repairList) {
        this.repairList = repairList;
    }

    public List<RentReportOtherVO> getOtherList() {
        return otherList;
    }

    public void setOtherList(List<RentReportOtherVO> otherList) {
        this.otherList = otherList;
    }

    public List<RentReportCalcVO> getCalcList() {
        return calcList;
    }

    public void setCalcList(List<RentReportCalcVO> calcList) {
        this.calcList = calcList;
    }
}

==> cscec5b-rmat-impl-3.0.1-20250120.095631-338-sources.jar: com/ejianc/business/rmat/vo/RentReportVO.java <==
package com.ejianc.business.rmat.vo;

import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 项目租金报表
 *
 * @author generator
 *
 */
public class RentReportVO {
    private static final long serialVersionUID = 1L;

    private Long id;
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date beginDate;
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date endDate;
    private BigDecimal totalMny;
    private BigDecimal rentMny;
    private BigDecimal otherMny;

    private List<RentReportDetailVO> detailList = new ArrayList<>();
    private List<RentReportRestituteVO> restituteList = new ArrayList<>();
    private List<RentReportRepairVO> repairList = new ArrayList<>();
    private List<RentReportOtherVO> otherList = new ArrayList<>();
    private List<RentReportCalcVO> calcList = new ArrayList<>();

    private List<RentReportDetailNewVO> detailNewList = new ArrayList<>();

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public BigDecimal getTotalMny() {
        return totalMny;
    }

    public void setTotalMny(BigDecimal totalMny) {
        this.totalMny = totalMny;
    }

    public BigDecimal getRentMny() {
        return rentMny;
    }

    public void setRentMny(BigDecimal rentMny) {
        this.rentMny = rentMny;
    }

    public BigDecimal getOtherMny() {
        return otherMny;
    }

    public void setOtherMny(BigDecimal otherMny) {
        this.otherMny = otherMny;
    }

    public List<RentReportDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<RentReportDetailVO> detailList) {
        this.detailList = detailList;
    }

    public List<RentReportRestituteVO> getRestituteList() {
        return restituteList;
    }

    public void setRestituteList(List<RentReportRestituteVO> restituteList) {
        this.restituteList = restituteList;
    }

    public List<RentReportRepairVO> getRepairList() {
        return repairList;
    }

    public void setRepairList(List<RentReportRepairVO> repairList) {
        this.repairList = repairList;
    }

    public List<RentReportOtherVO> getOtherList() {
        return otherList;
    }

    public void setOtherList(List<RentReportOtherVO> otherList) {
        this.otherList = otherList;
    }

    public List<RentReportCalcVO> getCalcList() {
        return calcList;
    }

    public void setCalcList(List<RentReportCalcVO> calcList) {
        this.calcList = calcList;
    }

    public List<RentReportDetailNewVO> getDetailNewList() {
        return detailNewList;
    }

    public void setDetailNewList(List<RentReportDetailNewVO> detailNewList) {
        this.detailNewList = detailNewList;
    }
}
